var gui = require('nw.gui');
var win = gui.Window.get();
var fs = require('fs');
var path = require('path');

var logfile;
var showing; // GUI showing

var inp = document.getElementById('inp');



function init(logfile) {
  if (!fs.existsSync(logfile)) {
    process.stderr.write("\nlogfile not found\n\n");
    return win.close();
  }

  var withoutExtension = logfile.substr(0, logfile.lastIndexOf('.'));
  var cssfile = withoutExtension + '.css';
  var className = path.basename(withoutExtension);
  document.body.className = className;
  if (fs.existsSync(cssfile)) {
    var link = document.createElement('link');
    link.setAttribute("rel", "stylesheet")
    link.setAttribute("type", "text/css")
    link.setAttribute("href", cssfile)
    document.getElementsByTagName('head')[0].appendChild(link);
  }
}

// Thanks Steven Moseley, stackoverflow!
function formatLocalDate() {
  var now = new Date(),
      tzo = -now.getTimezoneOffset(),
      dif = tzo >= 0 ? '+' : '-',
      pad = function(num) {
        var norm = Math.abs(Math.floor(num));
        return (norm < 10 ? '0' : '') + norm;
      };
      pad3 = function(num) {
        return (num < 100 ? (num < 10 ? '00' : '0')  : '') + num;
      }
  return now.getFullYear()
    + '-' + pad(now.getMonth()+1)
    + '-' + pad(now.getDate())
    + ' ' + pad(now.getHours())
    + ':' + pad(now.getMinutes())
    + ':' + pad(now.getSeconds())
    + '.' + pad3(now.getMilliseconds())
    + dif + pad(tzo / 60)
    + ':' + pad(tzo % 60);
}
function log(message) {
  var timestamp = formatLocalDate();
  fs.appendFile(logfile, timestamp + ' ' + message + "\n", function(err) {
    if (err) throw err;
  });
}

function hide() {
  win.hide();
  showing = false;
}



// More ~reopen; not executed 1st time
gui.App.on('open', function(cmd) {
  args = cmd.split(' ');
  if (args.length == 3) {
    logfile = args[2];
    init(logfile);
  }
  win.show();
  win.focus();
  showing = true;
});

if (gui.App.argv.length != 1) {
  process.stderr.write("\nusage: [nw] thought-logger path/to/log.file\n\n");
  win.close();
} else {
  logfile = gui.App.argv[0];
  init(logfile);
}



inp.onkeyup = function(e) {
  // XXX warning if this application was launched with [something]+ENTER
  // the event may be picked up here... you could perhaps add a delay / timeout
  if (e.keyCode == 13) {
    inp.submit();
  }
}
inp.submit = function(e) {
  var message = inp.value;
  inp.value = '';
  if (message.length) log(message);
  hide();
  return false;
}

window.onkeydown = function(e) {
  if (e.keyCode == 27) {
    (inp.value.length > 0) ? inp.value = '' : hide();
    return false;
  }
}
window.onload  = function(e) { inp.focus(); }
window.onclick = function(e) { inp.focus(); }
window.onfocus = function(e) { inp.focus(); }
